#define BUILD_NUMBER \
	"build-7253323"
#define BUILD_NUMBER_NUMERIC \
	7253323
#define BUILD_NUMBER_NUMERIC_STRING \
	"7253323"
#define PRODUCT_BUILD_NUMBER \
	"product-build-1608"
#define PRODUCT_BUILD_NUMBER_NUMERIC \
	1608
#define PRODUCT_BUILD_NUMBER_NUMERIC_STRING \
	"1608"
